pyramid_decoy
=============



.. image:: https://img.shields.io/pypi/v/pyramid_decoy.svg
    :target: https://pypi.python.org/pypi/pyramid_decoy/
    :alt: Latest PyPI version

.. image:: https://readthedocs.or/projects/pyramid_decoy/badge/?version=v0.2.0
    :target: http://pyramid_decoy.readthedocs.io/en/v0.2.0/
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/wheel/pyramid_decoy.svg
    :target: https://pypi.python.org/pypi/pyramid_decoy/
    :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/pyramid_decoy.svg
    :target: https://pypi.python.org/pypi/pyramid_decoy/
    :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/pyramid_decoy.svg
    :target: https://pypi.python.org/pypi/pyramid_decoy/
    :alt: License

pyramid_decoy, a simple pyramid app, which solely purpose is to redirect traffic away
to configured location, with hooks (in the future) to be able to plug in a tracking code.

Package resources
-----------------

* Bug tracker: https://github.com/fizyk/pyramid_decoy/issues
* Documentation: http://pyramid_decoy.readthedocs.org/




Travis-ci
---------

After creating package on github, move to tracis-ci.org, and turn on ci builds for given package.
